@@ -8,9 +8,17 @@ from pygasflow.solvers import (
     De_Laval_Solver
 )
 
+ise = isentropic_solver
+fan = fanno_solver
+ray = rayleigh_solver
+ss = shockwave_solver
+css = conical_shockwave_solver
+
 from pygasflow.nozzles import (
     CD_Conical_Nozzle,
     CD_Min_Length_Nozzle,
     CD_TOP_Nozzle,
     Rao_Parabola_Angles
 )
+
+from pygasflow.common import pressure_coefficient, sound_speed
